@@ -1,4 +1,12 @@
 #!/usr/bin/env python
+import warnings
+
+from ansible.module_utils.hashivault import hashivault_argspec
+from ansible.module_utils.hashivault import hashivault_auth_client
+from ansible.module_utils.hashivault import hashivault_init
+from ansible.module_utils.hashivault import hashiwrapper
+
+ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
 DOCUMENTATION = '''
 ---
 module: hashivault_list
@@ -14,13 +22,31 @@ options:
         description:
             - url for vault
         default: to environment variable VAULT_ADDR
+    ca_cert:
+        description:
+            - "path to a PEM-encoded CA cert file to use to verify the Vault server TLS certificate"
+        default: to environment variable VAULT_CACERT
+    ca_path:
+        description:
+            - "path to a directory of PEM-encoded CA cert files to verify the Vault server TLS certificate : if ca_cert
+             is specified, its value will take precedence"
+        default: to environment variable VAULT_CAPATH
+    client_cert:
+        description:
+            - "path to a PEM-encoded client certificate for TLS authentication to the Vault server"
+        default: to environment variable VAULT_CLIENT_CERT
+    client_key:
+        description:
+            - "path to an unencrypted PEM-encoded private key matching the client certificate"
+        default: to environment variable VAULT_CLIENT_KEY
     verify:
         description:
-            - verify TLS certificate
+            - "if set, do not verify presented TLS certificate before communicating with Vault server : setting this
+             variable is not recommended except during testing"
         default: to environment variable VAULT_SKIP_VERIFY
     authtype:
         description:
-            - authentication type to use: token, userpass, github, ldap
+            - "authentication type to use: token, userpass, github, ldap, approle"
         default: token
     token:
         description:
@@ -29,19 +55,19 @@ options:
     username:
         description:
             - username to login to vault.
-        default: False
+        default: to environment variable VAULT_USER
     password:
         description:
             - password to login to vault.
-        default: False
+        default: to environment variable VAULT_PASSWORD
     secret:
         description:
-            - secret path to list.  If this does not begin with a C(/)
+            - 'secret path to list.  If this does not begin with a C(/)
               then it is interpreted as a subpath of C(/secret).  This
               is always interpreted as a "directory": if a key C(/secret/foo)
               exists, and you pass C(/secret/foo) as I(secret), then the key
               itself will not be returned, but subpaths like
-              C(/secret/foo/bar) will.
+              C(/secret/foo/bar) will.'
         default: ''
 '''
 RETURN = '''
@@ -74,10 +100,6 @@ def main():
         module.exit_json(**result)
 
 
-from ansible.module_utils.basic import *
-from ansible.module_utils.hashivault import *
-
-
 @hashiwrapper
 def hashivault_list(params):
     result = {"changed": False, "rc": 0}
